this.author      = "cim"; 
this.copyright   = "2011-2012 cim. 2014 spara."; 
this.licence = "CC-BY-SA 3.0";
this.version     = "1.3.3"; 
this.name        = "Rescue Scenario 1"; 
this.description = "This script adds scenario 1 rescue mission."; 

//1.3.3 new method for selecting the mission ship
//1.3 added background images to mission screens -spara-
//1.3 random shipnames integration -spara-

this.scenarioID = "1";

this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerScenario(this.scenarioID);
}

this.missionAvailableCount = function() {
		return 1;
}

this.targetSystems = function() {
		return SystemInfo.filteredSystems(this, function (other) {
				return (other.systemID !== system.info.systemID) && 
						(!other.sun_gone_nova) &&
						(system.info.distanceToSystem(other) <= 7) &&
						(other.government < 5) // communist or less stable
		});
}

this.missionAvailable = function() {
		nearby = this.targetSystems();
		if (nearby.length == 0) {
				return false; // no suitable nearby systems
		}
		if (missionVariables.rescuestation_reputation < 10) {
				return false; // insufficient reputation
		}
		if (player.bounty > 50) {
				return false; // no fugitives
		}
		if (Math.random() < 0.2) {
				return true; // not usually available
		}
		return false;
}

this.initMissionVariables = function() {
		var nearby = this.targetSystems();
// we don't get here unless nearby.length > 0
		var destination = nearby[Math.floor(nearby.length*Math.random())];

		missionVariables.rescuestation_danger1 = 1+worldScripts["Rescue Stations"].dangerScale(512);
		missionVariables.rescuestation_danger2 = 3+worldScripts["Rescue Stations"].dangerScale(256);
		missionVariables.rescuestation_leader_home = 0;
		missionVariables.rescuestation_derelict_home = 0;
		missionVariables.rescuestation_startsystem = system.ID;
		missionVariables.rescuestation_destsystem = destination.systemID;
		missionVariables.rescuestation_destsystem_name = destination.name;
		missionVariables.rescuestation_destsystem_type = "[rescue_govtype_"+destination.government+"]";

		var choosetype = this.$selectShip();
		missionVariables.rescuestation_shiprole = choosetype[0];
		
		if (worldScripts.randomshipnames)
			missionVariables.rescuestation_shiprole2 = choosetype[1] + ": " +  worldScripts.randomshipnames.$randomTraderName(player.ship);
		else 
			missionVariables.rescuestation_shiprole2 = choosetype[1];
				
		missionVariables.rescuestation_missionwingsize = 1;
		missionVariables.rescuestation_wingname = expandDescription("[rescue_wingnames]");

		var reward = 500;

		missionVariables.rescuestation_reward = reward;
		missionVariables.rescuestation_livefire = 0;

}

//Randomly choose a ship for the mission
this.$selectShip = function() {
	var dataKeys = Ship.keysForRole("rescue_target");
	var index = Math.floor(Math.random() * dataKeys.length);
	var shipKey = dataKeys[index];
	var roles = Ship.shipDataForKey(shipKey)["roles"].split(" ");
	for (var i = 0; i < roles.length; i++) {
		if (roles[i] != "rescue_target" && roles[i].indexOf("rescue_target") != -1) {
			return [roles[i], Ship.shipDataForKey(shipKey)["name"]];
		}
	}	
}

this.rescue_shipDockedWithStation = function (rstation) {
		if (missionVariables.rescuestation_stage > 0) {
				if (missionVariables.rescuestation_stage > 1) {
						if (missionVariables.rescuestation_stage < 1000) {
								player.commsMessage("You have docked before the rescue mission was complete. You will not be paid for this breach of contract!",7);
								worldScripts["Rescue Stations"].failMission();
						}
				}
		} 
}

this.rescue_missionScreenOpportunity = function() {
		if (missionVariables.rescuestation_stage == 1) {
				mission.runScreen ({title: "URGENT: Rescue Mission Escorts Needed",
														messageKey: "rescue_scenario_1_mission_available",
														choicesKey: "rescue_scenario_urgent_mission_choices",
														model: missionVariables.rescuestation_shiprole,
														background: "rrsfl_blank_bg.png"},
													 this.missionOfferDecision
													);
		} else if (missionVariables.rescuestation_stage == 1000) {
				reward = missionVariables.rescuestation_reward;
				if (missionVariables.rescuestation_livefire == 1) {
						reward = Math.round(reward*1.33);
						missionVariables.rescuestation_reward = reward;
				}
				player.credits += reward;

				mission.runScreen({title: "Rescue mission completed",
													 messageKey: "rescue_scenario_1_mission_complete",
													 /*model: "EQ_RESCUE_MISSILE",*/
													 background: "rrsfl_bg.png",});

				worldScripts["Rescue Stations"].missionSuccess();

		}
}


this.rescue_shipWillLaunchFromStation = function (rstation) {
		if (missionVariables.rescuestation_stage == 2 && rstation.hasRole("rescue_station")) {
				addpos = rstation.position.add([0,0,10E6-5E3]);
				
				leader = system.addShips("rescue_team_lead",1,addpos,10);
				leader[0].orientation = leader[0].orientation.rotateY(Math.PI);
				leader[0].position = rstation.position.add([0,0,-5E3]);
				for(i=0;i<leader[0].escorts.length;i++) {
						escort = leader[0].escorts[i];
						escort.orientation = escort.orientation.rotateY(Math.PI);
						escort.position = leader[0].position.add([1500-(Math.random()*3000),500-(Math.random()*1000),0.6E3*(1+i)]);
						escort.speed = escort.maxSpeed/3;
				}
				
				missionVariables.rescuestation_stage = 3;
		}

}

this.rescue_populatingSystem = function() {
		if (missionVariables.rescuestation_stage == 10 && system.ID == missionVariables.rescuestation_destsystem) {
				missionVariables.rescuestation_stage = 11;

//				addpos = this.randomOffset(60E3);
				addpos = this.randomOffset(150E3*(1+(2*Math.random())));

				var addedShip = system.addShips(missionVariables.rescuestation_shiprole,1,addpos,1);

				if (worldScripts.randomshipnames)
					addedShip[0].displayName = missionVariables.rescuestation_shiprole2;
				else
					addedShip[0].displayName = addedShip[0].name + " (derelict)";

				addpos2 = addpos.direction().multiply(80E3*Math.random());
				
				if (Math.random()+(system.government/20) < 0.85) {
						pirates = system.addShips("pirate",missionVariables.rescuestation_danger1+Math.floor(Math.random()*missionVariables.rescuestation_danger2),addpos2,3E3);
						this.forceAssault(pirates);
				}

				if (addpos.magnitude() > 200E3) {
						addpos2 = addpos.direction().multiply(100E3+(80E3*Math.random()));

						if (Math.random()+(system.government/20) < 0.85) {
								pirates = system.addShips("pirate",missionVariables.rescuestation_danger1+Math.floor(Math.random()*missionVariables.rescuestation_danger2),addpos2,3E3);
						}
						
				}

		}

}

this.rescue_shipWillExitWitchspace = function() {
		
}

/* Mission setup */

this.missionSuccess = function() {
		missionVariables.rescuestation_reputation += 5;
		if (missionVariables.rescuestation_livefire == 1) {
				missionVariables.rescuestation_reputation += 5;
		}
		
		worldScripts["Rescue News"].sendNews("rescue_scenario_1_news",0,0.03);
}

this.failMission = function () {
		missionVariables.rescuestation_reputation -= 5;
		// nothing special
}

this.cleanupMission = function() {
		delete missionVariables.rescuestation_callsign;
		delete missionVariables.rescuestation_missionwingsize;
		delete missionVariables.rescuestation_wingname;
		delete missionVariables.rescuestation_startsystem;
		delete missionVariables.rescuestation_destsystem;
		delete missionVariables.rescuestation_destsystem_name;
		delete missionVariables.rescuestation_destsystem_type;
		delete missionVariables.rescuestation_shiprole;
		delete missionVariables.rescuestation_shiprole2;
		delete missionVariables.rescuestation_leader_home;
		delete missionVariables.rescuestation_derelict_home;
		delete missionVariables.rescuestation_livefire;
		delete missionVariables.rescuestation_reward;
		delete missionVariables.rescuestation_danger1;
		delete missionVariables.rescuestation_danger2;

}

this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Downloading mission data",
													 messageKey: "rescue_scenario_1_mission_accepted",
													 choicesKey: "rescue_scenario_urgent_mission_launch",
													 model: "rescue_team_lead",
													 background: "rrsfl_blank_bg.png",},
													worldScripts["Rescue Scenario 1"].missionOfferAccepted
												 );
		}
}

this.missionOfferAccepted = function (choice) {
		worldScripts["Rescue Stations"].acceptMission();
		worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_1_description");
		player.ship.fuel = 7;
		player.ship.launch();
}

/* Mission functions */

this.followToDest = function(mass) {
		expirytime = 50 + (mass/4000);
		this.followtimer = new Timer (this, this.checkFollowed, expirytime);
}

this.checkFollowed = function() {
		if (missionVariables.rescuestation_stage > 0) {
				if (system.countShipsWithRole("arafura-mission") == 0) {
						player.consoleMessage("You have failed to follow your leader through witch-space. Mission failed",7);
						this.failMission();
				}
		}
}

this.forceAssault = function(attackers) {
		for(i=0;i<attackers.length;i++) {
				targets = system.filteredEntities(this,function(entity) {
						return (entity == player.ship) || (entity.hasRole == "arafura-mission");
				},attackers[i],25600);
				if (targets.length > 0) {
						target = targets[Math.floor(Math.random()*targets.length)];
						attackers[i].target = target;
						attackers[i].setAI("interceptAI.plist");
				}
		}
}

this.randomOffset = function(basedist) {
		return Vector3D.randomDirection(basedist);
}
