this.author      = "cim"; 
this.copyright   = "� 2011-2012 cim."; 
this.licence = "CC-BY-SA 3.0";
this.version     = "1.3"; 
this.name        = "Rescue Scenario 1b"; 
this.description = "This script adds scenario 1 variant B rescue mission."; 

//1.3 added background images to mission screens -spara-
//1.3 random shipnames integration -spara-
//1.3 anomalies added as visual effects -spara-


this.scenarioID = "1b";

this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerVariant("1",this.scenarioID);
}

this.missionAvailableCount = function() {
		return 1;
}

this.missionAvailable = function() {
		if (missionVariables.rescuestation_reputation < 40) {
				return false; // Tier 3 contractor needed
		}
		if (worldScripts["Rescue Stations"].scenariosWon("1") < 5) {
				return false; // somewhat rare variation
		}
		if (10*worldScripts["Rescue Stations"].scenariosWon("1") > worldScripts["Rescue Stations"].scenariosTried("1b")) {
				return false; // no more than 1 in 10
		}
		if (Math.random() < 0.3) {
				return true; // occasional replacement
		}
		return false;
}

this.initMissionVariables = function() {
		worldScripts["Rescue Scenario 1"].initMissionVariables();
}

this.rescue_shipDockedWithStation = function (rstation) {
		worldScripts["Rescue Scenario 1"].rescue_shipDockedWithStation(rstation);
}

this.rescue_missionScreenOpportunity = function() {
		if (missionVariables.rescuestation_stage == 1) {
				mission.runScreen ({title: "URGENT: Rescue Mission Escorts Needed",
														messageKey: "rescue_scenario_1b_mission_available",
														choicesKey: "rescue_scenario_urgent_mission_choices",
														model: missionVariables.rescuestation_shiprole,
														background: "rrsfl_blank_bg.png"},
													 this.missionOfferDecision
													);
		} else if (missionVariables.rescuestation_stage == 1000) {
				reward = missionVariables.rescuestation_reward;
				if (missionVariables.rescuestation_livefire == 1) {
						reward = Math.round(reward*1.5);
						missionVariables.rescuestation_reward = reward;
				}
				player.credits += reward;

				mission.runScreen({title: "Rescue mission completed",
													 messageKey: "rescue_scenario_1b_mission_complete",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].missionSuccess();

		}
}


this.rescue_shipWillLaunchFromStation = function (rstation) {
		if (missionVariables.rescuestation_stage == 2 && rstation.hasRole("rescue_station")) {
				addpos = rstation.position.add([0,0,10E6-5E3]);
				
				leader = system.addShips("rescue_team_lead_2",1,addpos,10);
				leader[0].orientation = leader[0].orientation.rotateY(Math.PI);
				leader[0].position = rstation.position.add([0,0,-5E3]);
				for(i=0;i<leader[0].escorts.length;i++) {
						escort = leader[0].escorts[i];
						escort.orientation = escort.orientation.rotateY(Math.PI);
						escort.position = leader[0].position.add([1500-(Math.random()*3000),500-(Math.random()*1000),0.6E3*(1+i)]);
						escort.speed = escort.maxSpeed/3;
				}
				
				missionVariables.rescuestation_stage = 3;
		}
}


this.rescue_populatingSystem = function() {
		if (missionVariables.rescuestation_stage == 10 && missionVariables.rescuestation_destsystem == system.ID) {
				missionVariables.rescuestation_stage = 11;

				addpos = this.randomOffset(100E3*(1+(2*Math.random())));

				var addedShip = system.addShips(missionVariables.rescuestation_shiprole,1,addpos,1);

				if (worldScripts.randomshipnames)
					addedShip[0].displayName = missionVariables.rescuestation_shiprole2;
				else
					addedShip[0].displayName = addedShip[0].name + " (derelict)";
				

		} else if (missionVariables.rescuestation_stage == 100 && missionVariables.rescuestation_startsystem == system.ID) {
				danger1 = Math.floor(Math.random()*(missionVariables.rescuestation_danger1-1));
				if (danger1 > 0) {
					for (var i = 0; i < danger1; i++)
						system.addVisualEffect("rrs_witchspace_anomaly",Vector3D.randomDirectionAndLength(20E3));
				}
				if (worldScripts["GalNavy"] && Math.random() < 0.8) { // Galactic Navy OXP available
						system.addShips("patrol-frigate",1,[0,0,0],10E3);
						danger2 = Math.floor(0.5*Math.random()*missionVariables.rescuestation_danger2);
						if (danger2 > 0) {
							for (var i = 0; i < danger2; i++)
								system.addVisualEffect("rrs_witchspace_anomaly",Vector3D.randomDirectionAndLength(20E3));
						}
				}
				
		}
}

/* Mission setup */

this.missionSuccess = function() {
		missionVariables.rescuestation_reputation += 5;
		if (missionVariables.rescuestation_livefire == 1) {
				// basically always
				missionVariables.rescuestation_reputation += 10;
		}
		// nothing special		
}

this.failMission = function () {
		missionVariables.rescuestation_reputation -= 5;
		// nothing special
}

this.cleanupMission = function() {
		worldScripts["Rescue Scenario 1"].cleanupMission();
}

this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Downloading mission data",
													 messageKey: "rescue_scenario_1_mission_accepted",
													 choicesKey: "rescue_scenario_urgent_mission_launch",
													 model: "rescue_team_lead",
													 background: "rrsfl_blank_bg.png"},
													worldScripts["Rescue Scenario 1b"].missionOfferAccepted
												 );
		}
}

this.missionOfferAccepted = function (choice) {
		worldScripts["Rescue Stations"].acceptMission();
		worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_1_description");
		player.ship.fuel = 7;
		player.ship.launch();
}

/* Mission functions */

this.followToDest = function(mass) {
		expirytime = 50 + (mass/4000);
		this.followtimer = new Timer (this, this.checkFollowed, expirytime);
}

this.checkFollowed = function() {
		worldScripts["Rescue Scenario 1"].checkFollowed();
}

this.forceAssault = function(attackers) {
		worldScripts["Rescue Scenario 1"].forceAssault(attackers);
}

this.randomOffset = function(basedist) {
		return worldScripts["Rescue Scenario 1"].randomOffset(basedist);
}

