this.author      = "cim"; 
this.copyright   = "� 2011-2012 cim."; 
this.licence = "CC-BY-SA 3.0";
this.version     = "1.3"; 
this.name        = "Rescue Scenario 4a"; 
this.description = "This script adds scenario 4a rescue mission."; 

//1.3 removed beacon buoy and added beacon to the base instead
//1.3 fixed description expand bug -spara-
//1.3 added background images to mission screens -spara-

this.scenarioID = "4a";

/* Stages:
 * 2: mission accepted
 * 10: base location given
 * 30: base has launched slaver
 * 40: slaver launching pods
 * 41-45: slaver pods collected
 * 100: rescue complete
 * 1000: mission complete
 * 1001: mission completed too late
 */

this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerVariant("4",this.scenarioID);
}

this.missionAvailable = function() {
		if (Math.random() > 0.6) {
				return false; // often available
		}
		if (worldScripts["Rescue Stations"].scenariosWon("4") == 0) {
				return false; // must complete one base one before any variants start appearing
		}
		if (missionVariables.rescuestation_reputation < 20) {
				return false; // need some rep to start doing these
		}
		if (player.bounty > 50) {
				return false; // no fugitives
		}
		if (player.ship.equipmentStatus("EQ_FUEL_SCOOPS") != "EQUIPMENT_OK") {
				return false; // needs fuel scoops, secretly
		}
		if (player.ship.equipmentStatus("EQ_ADVANCED_COMPASS") != "EQUIPMENT_OK") {
				return false; // needs advanced compass, secretly
		}
		nearby = this.targetSystems();
		if (nearby.length == 0) {
				return false; // nowhere suitable (rare!)
		}
		return true;
}

this.targetSystems = function() {
		return SystemInfo.filteredSystems(this, function (other) {
				if (!((other.systemID !== system.info.systemID) && 
						(!other.sun_gone_nova) &&
						(other.government <= 1) && // feudal or less
							(system.info.distanceToSystem(other) < 15))) {
						return false;
				} else {
						var route = system.info.routeToSystem(other);
						return (route && route.distance <= 25);
				}
		});
}


this.initMissionVariables = function() {

		missionVariables.rescuestation_system = system.ID;
		missionVariables.rescuestation_system_name = system.name; 
		systems = this.targetSystems();
		
		destsystem = systems[Math.floor(Math.random()*systems.length)];
		
		missionVariables.rescuestation_destsystem = destsystem.systemID;
		missionVariables.rescuestation_destsystem_name = destsystem.name;

		direction = worldScripts["Rescue Stations"].getDirection(system.info,destsystem);
		missionVariables.rescuestation_destsystem_desc = destsystem.name+" ("+expandDescription("[rescue_govname_"+destsystem.government+"]")+", "+Math.round(system.info.distanceToSystem(destsystem))+" LY "+direction+")";

		deadline = clock.seconds+(3600*system.info.routeToSystem(destsystem).time*(2.2+Math.random()));
		missionVariables.rescuestation_deadline = deadline;
		missionVariables.rescuestation_deadline_text = clock.clockStringForTime(deadline);

		missionVariables.rescuestation_pilot = randomName()+" "+randomName();
		missionVariables.rescuestation_pilotdesc = randomInhabitantsDescription(false);

		reward = Math.floor((3*system.info.routeToSystem(destsystem).distance-destsystem.government) * 15);

		missionVariables.rescuestation_reward = reward;


		danger1 = 2+worldScripts["Rescue Stations"].dangerScale(256); 
		danger2 = 3+worldScripts["Rescue Stations"].dangerScale(128);

		missionVariables.rescuestation_danger1 = danger1;
		missionVariables.rescuestation_danger2 = danger2;

}

this.rescue_shipDockedWithStation = function (rstation) {

		if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_system && missionVariables.rescuestation_stage >= 100) {
				if (clock.seconds < missionVariables.rescuestation_deadline) {
						missionVariables.rescuestation_stage = 1000;
				} else {
						missionVariables.rescuestation_stage = 1001;
				}
		} else if (rstation.isMainStation && system.ID == missionVariables.rescuestation_destsystem && missionVariables.rescuestation_stage < 10) {
				missionVariables.rescuestation_stage = 10;
		} else if (missionVariables.rescuestation_stage >= 40 && missionVariables.rescuestation_stage < 50) {
				if (rstation.isMainStation || rstation.hasRole("rescue_station")) {
						rescued = missionVariables.rescuestation_stage-40;
						if (rescued == 0) {
								player.consoleMessage("You're out of leads. "+missionVariables.rescuestation_pilot+" is either dead or MIA.");
								worldScripts["Rescue Stations"].failMission();
						} else if (Math.random()*5 < rescued) {
								missionVariables.rescuestation_stage = 90; // rescued!
								player.credits += rescued*50;
								missionVariables.rescuestation_reputation += rescued;
						} else {
								missionVariables.rescuestation_stage = 80; // missed their pod
								player.credits += rescued*50;
								missionVariables.rescuestation_reputation += rescued*5;
								// going to get hit for -30 for failing, so give some mitigation for doing roughly the right thing
						}
						worldScripts["Rescue News"].sendNews("rescue_scenario_4a_news",0,0.02*rescued); // maybe someone famous was rescued?


						missionVariables.rescuestation_reward2 = rescued*50;

				}
		}

}

this.rescue_missionScreenOpportunity = function() {
		rstation = player.ship.dockedStation;
		if (rstation.hasRole("rrs_slaverbase")) {
				mission.runScreen ({title: "That was a bad idea",
														messageKey: "rescue_slaverbase_eject",
														model: "rrs_slaverbase",
														background: "rrsfl_blank_bg.png"},
													 this.slaverEjectPlayer
													);
		} else if (missionVariables.rescuestation_stage == 1) {
				mission.runScreen ({title: "Personnel recovery needed",
														messageKey: "rescue_scenario_4a_mission_available",
														choicesKey: "rescue_scenario_nonurgent_mission_choices",
														model: "rescue_station",
														background: "rrsfl_blank_bg.png"},
													 this.missionOfferDecision
													);
		} else if (missionVariables.rescuestation_stage == 1000) {
				reward = missionVariables.rescuestation_reward;
				player.credits += reward;

				mission.runScreen({title: "Recovery completed",
													 messageKey: "rescue_scenario_4a_mission_complete",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].missionSuccess();
		} else if (missionVariables.rescuestation_stage == 1001) {
				reward = missionVariables.rescuestation_reward;
				player.credits += reward;

				mission.runScreen({title: "Recovery completed",
													 messageKey: "rescue_scenario_4a_mission_toolate",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].failMission();

		} else if (missionVariables.rescuestation_stage == 10) {
				mission.runScreen({title: "Bad news",
													 messageKey: "rescue_scenario_4a_mission_contacts",
													 model: "police",
													 background: "rrsfl_blank_bg.png"});

				this.markSlavers();
				worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_4a_description");
				
				missionVariables.rescuestation_stage = 11;
		} else if (missionVariables.rescuestation_stage == 80) {
				if (rstation.hasRole("rescue_station")) {
						mmodel = "rescue_station";
				} else {
						mmodel = "police";
				}
				mission.runScreen({title: "Mission failed",
													 messageKey: "rescue_scenario_4a_mission_partfail",
													 model: mmodel,
													 background: "rrsfl_blank_bg.png"});

				worldScripts["Rescue Stations"].failMission();
		} else if (missionVariables.rescuestation_stage == 90) {
				if (rstation.hasRole("rescue_station")) {
						mmodel = "rescue_station";
				} else {
						mmodel = "police";
				}
				mission.runScreen({title: "Pilot rescued!",
													 messageKey: "rescue_scenario_4a_mission_rescued1",
													 model: mmodel,
													 background: "rrsfl_blank_bg.png"});
				if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_system) {
						if (clock.seconds < missionVariables.rescuestation_deadline) {
								missionVariables.rescuestation_stage = 1000;
						} else {
								missionVariables.rescuestation_stage = 1001;
						}
				} else {
						missionVariables.rescuestation_stage = 91;
				}
				mission.unmarkSystem(missionVariables.rescuestation_destsystem);
		} else if (missionVariables.rescuestation_stage == 91) {
				mission.runScreen({title: "Pilot rescued!",
													 messageKey: "rescue_scenario_4a_mission_rescued2",
													 model: player.ship.dockedStation.primaryRole,
													 background: "rrsfl_blank_bg.png"});

// in case the home station is the first one visited
				if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_system) {
						if (clock.seconds < missionVariables.rescuestation_deadline) {
								missionVariables.rescuestation_stage = 1000;
						} else {
								missionVariables.rescuestation_stage = 1001;
						}
				} else {
						missionVariables.rescuestation_stage = 100;
						mission.markSystem(missionVariables.rescuestation_system);
				}
				mission.unmarkSystem(missionVariables.rescuestation_destsystem);

		}

}


this.rescue_populatingSystem = function (rstation) {
		if (system.ID == missionVariables.rescuestation_destsystem) {
				this.addSlaverBase();
		}
}


this.rescue_shipExitedWitchspace = function() {
		if (missionVariables.rescuestation_stage < 10 && clock.seconds > missionVariables.rescuestation_deadline) {
				player.commsMessage(missionVariables.rescuestation_system_name+" RRS: We've just received news that "+missionVariables.rescuestation_pilot+" has been captured by slavers and taken out of the system. Return to base: we'll get someone more reliable to track them down.");
				worldScripts["Rescue Stations"].failMission();
		}

}

/* Mission setup */

this.missionSuccess = function() {
		mission.unmarkSystem(missionVariables.rescuestation_destsystem);
		mission.unmarkSystem(missionVariables.rescuestation_system);
		missionVariables.rescuestation_reputation += 10;
		// nothing special		
}

this.failMission = function () {
		if (missionVariables.rescuestation_stage < 100) {
				mission.unmarkSystem(missionVariables.rescuestation_destsystem);
		} else {
				mission.unmarkSystem(missionVariables.rescuestation_system);
		}
		if (missionVariables.rescuestation_stage != 1001) {
				missionVariables.rescuestation_reputation -= 30; // really bad
		}
}

this.cleanupMission = function() {
		delete missionVariables.rescuestation_reward;
		delete missionVariables.rescuestation_reward2;
		delete missionVariables.rescuestation_system;
		delete missionVariables.rescuestation_system_name;
		delete missionVariables.rescuestation_destsystem;
		delete missionVariables.rescuestation_destsystem_name;
		delete missionVariables.rescuestation_destsystem_desc;
		delete missionVariables.rescuestation_deadline;
		delete missionVariables.rescuestation_deadline_text;
		delete missionVariables.rescuestation_pilot;
		delete missionVariables.rescuestation_pilotdesc;
		delete missionVariables.rescuestation_danger1;
		delete missionVariables.rescuestation_danger2;
}


this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Good luck",
													 messageKey: "rescue_scenario_4_mission_accepted",
													 model: "rescue_station",
													 background: "rrsfl_blank_bg.png"},
													function (choice) {
															worldScripts["Rescue Stations"].acceptMission();
															worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_4_description");
													}
												 );
				mission.markSystem(missionVariables.rescuestation_destsystem);
				
		}
}

/* Mission functions */


this.addSlaverBase = function() {
		
				pos = Vector3D(0, 0, 0.5).fromCoordinateSystem("wpu");
				xrange = Math.random();
				yrange = Math.sqrt(1-(xrange*xrange));
				if (Math.random() < 0.5) { xrange = -xrange; }
				if (Math.random() < 0.5) { yrange = -yrange; }
				distance = 100E3+(Math.random()*100E3);
				sbpos = pos.add([xrange*distance,yrange*distance,0]);
				
				slaverbase = system.addShips("rrs_slaverbase",1,sbpos,20E3);
				slaverbase[0].orientation = Quaternion.random();

				pirates = system.addGroup("pirate",missionVariables.rescuestation_danger1+Math.floor(Math.random()*missionVariables.rescuestation_danger2),slaverbase[0].position,10E3);
				for (i=0;i<pirates.ships.length;i++) {
						pirates.ships[i].setScript("rescue_scenario_4a_sbdef.js");
						pirates.ships[i].switchAI("rescue_scenario_4a_sbdefAI.plist");
						pirates.ships[i].primaryRole = "sbdefender";
						pirates.ships[i].bounty += Math.floor(Math.random()*50);
				}
				if (missionVariables.rescuestation_stage > 10) {
						this.markSlavers();
				}

}

this.markSlavers = function() {
		getsb = system.shipsWithRole("rrs_slaverbase");
		getsb[0].beaconCode = "Slaver Base";
}

this.slaverEjectPlayer = function(choice) {
		player.ship.energy = 10;
		player.ship.forwardShield = 0;
		player.ship.aftShield = 0;
		player.ship.launch();
		rstation.commsMessage("And stay out!");
}
