this.author      = "cim"; 
this.copyright   = "� 2011-2012 cim."; 
this.licence = "CC-BY-SA 3.0";
this.version     = "1.3"; 
this.name        = "Rescue Scenario 4b"; 
this.description = "This script adds scenario 4b rescue mission."; 

//1.3 added background image to mission screens -spara-

this.scenarioID = "4b";

this.agenttimer = undefined;
this.agenttimer2 = undefined;

/* Stages:
 * 2: mission accepted
 * 10: meet with agent
 * 20: met with agent
 * 30: reached astromine (deadline applies)
 * 40: waiting for hacking
 * 50: roster hacked
 * 70: player launches
 * 80: miner launches
 * 90: system ships go hostile (will need a non-following AI)
 * 100: reached home system
 * 900: miner docks with RRS
 * 1000: mission complete
 * 1001: redock with astromine after launching (fails, badly)
 * 1002: arrive at astromine too late (already dead)
 */

this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerVariant("4",this.scenarioID);
}

this.missionAvailable = function() {
		if (worldScripts["Rescue Stations"].scenariosWon("4a") == 0) {
				return false; // must complete one normal slave rescue first
		}
		if (missionVariables.rescuestation_reputation < 80) {
				return false; // Tier 4 Contractor
		}
		if (worldScripts["Rescue Stations"].scenariosTried("4b") > worldScripts["Rescue Stations"].scenariosTried("4a")*10) {
				return false; // relatively rare
		}
		if (player.ship.equipmentStatus("EQ_RRS_FLIGHTFORM") != "EQUIPMENT_OK") {
				return false; // needs formation flight computer, secretly
		}
		nearby = this.targetSystems();
		if (nearby.length == 0) {
				return false; // nowhere suitable (often the case)
		}
		if (Math.random() < 0.3) {
				return true; // sometimes available in that case
		}
		return false;
}

this.targetSystems = function() {
		return SystemInfo.filteredSystems(this, function (other) {
				return (other.systemID !== system.info.systemID) && 
						(!other.sun_gone_nova) &&
						(other.government == 4) && // communist
						(system.info.distanceToSystem(other) < 7);
		});
}

this.initMissionVariables = function() {

		missionVariables.rescuestation_system = system.ID;
		missionVariables.rescuestation_system_name = system.name; 
		systems = this.targetSystems();
		
		destsystem = systems[Math.floor(Math.random()*systems.length)];
		
		missionVariables.rescuestation_destsystem = destsystem.systemID;
		missionVariables.rescuestation_destsystem_name = destsystem.name;
		
		deadline = clock.seconds+(3600*system.info.routeToSystem(destsystem).time*(1.5+Math.random()));
		missionVariables.rescuestation_deadline = deadline;

		missionVariables.rescuestation_pilot = randomName()+" "+randomName();
		missionVariables.rescuestation_pilotdesc = randomInhabitantsDescription(false);

		missionVariables.rescuestation_agent = randomName()+" "+randomName();
		missionVariables.rescuestation_agentdesc = randomInhabitantsDescription(false);

		missionVariables.rescuestation_reward = 1250;
}

this.rescue_shipDockedWithStation = function (rstation) {
		stage = missionVariables.rescuestation_stage;
		if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_system && stage >= 900) {
				missionVariables.rescuestation_stage = 1000;
		} else if (rstation.isMainStation && system.ID == missionVariables.rescuestation_destsystem && stage < 10) {
				missionVariables.rescuestation_stage = 10;
		} else if (rstation.hasRole("rrs_astromine") && stage >= 20 && stage < 30) {
				if (clock.seconds < missionVariables.rescuestation_deadline) {
						missionVariables.rescuestation_stage = 30;
				} else {
						missionVariables.rescuestation_stage = 1002;
				}
		} else if (rstation.hasRole("rrs_astromine") && stage > 70) {
				missionVariables.rescuestation_stage = 1001;
		}
}

this.rescue_missionScreenOpportunity = function() {
		stage = missionVariables.rescuestation_stage;

		if (stage == 1) {
				mission.runScreen ({title: "Urgent assistance needed",
														messageKey: "rescue_scenario_4b_mission_available",
														choicesKey: "rescue_scenario_nonurgent_mission_choices",
														model: "rescue_station",
														background: "rrsfl_blank_bg.png"},
													 this.missionOfferDecision
													);
		} else if (stage == 10) {
				mission.runScreen ({title: "The situation is bad",
														messageKey: "rescue_scenario_4b_meetagent",
														model: "rrs_astromine",
														background: "rrsfl_blank_bg.png"});
				missionVariables.rescuestation_stage = 20;
		} else if (stage == 30) {
				mission.runScreen ({title: "Be ready to leave fast",
														messageKey: "rescue_scenario_4b_splitup",
														model: "rrs_astromine",
														background: "rrsfl_blank_bg.png"});
				missionVariables.rescuestation_stage = 40;
				this.agenttimer = clock.seconds
				// start timer to set stage to 50
		} else if (stage == 50) {
				mission.runScreen ({title: "Here's the plan",
														messageKey: "rescue_scenario_4b_timetogo",
														model: "rrs_astromine",
														background: "rrsfl_blank_bg.png"});
				missionVariables.rescuestation_stage = 60;
		} else if (stage == 1000) {
				player.credits += missionVariables.rescuestation_reward;
				mission.runScreen({title: "Recovery completed",
													 messageKey: "rescue_scenario_4b_mission_complete",
													 background: "rrsfl_bg.png"});
				worldScripts["Rescue Stations"].missionSuccess();
		} else if (stage == 1001) {
				mission.runScreen({title: "What are we doing back here?",
													 messageKey: "rescue_scenario_4b_mission_gowrong",
													 background: "rrsfl_bg.png"});
				missionVariables.rescuestation_reputation -= 5; // seriously bad
				worldScripts["Rescue Stations"].failMission();
		} else if (stage == 1002) {
				mission.runScreen({title: "We're too late",
													 messageKey: "rescue_scenario_4b_mission_toolate",
													 background: "rrsfl_bg.png"});
				worldScripts["Rescue Stations"].failMission();
		}

}

this.rescue_guiScreenChanged = function(to, from) {
		if (player.ship.dockedStation && player.ship.dockedStation.hasRole("rrs_astromine")) {
				if (missionVariables.rescuestation_stage == 40) {
						if (this.agenttimer + 60 < clock.seconds) {
								missionVariables.rescuestation_stage = 50;
						}
				}
				if (missionVariables.rescuestation_stage == 50) {
						if (guiScreen == to && (from == "GUI_SCREEN_STATUS" || to == "GUI_SCREEN_STATUS")) {
								this.rescue_missionScreenOpportunity();
						}
				}
		}
}

this.rescue_shipWillLaunchFromStation = function(rstation) {
		if (missionVariables.rescuestation_stage == 60) {
				missionVariables.rescuestation_stage = 70;
				system.addShips("rrs_astroguard",3,rstation.position,20E3);
				this.agenttimer = new Timer(this,rstation.script.launchRRS,30);
				this.agenttimer2 = new Timer(this,rstation.script.launchDefence,65);
		}
}

this.rescue_populatingSystem = function (rstation) {
		if (system.ID == missionVariables.rescuestation_destsystem) {
				this.addAstroMine();
		}
}

/* Mission setup */

this.missionSuccess = function() {
		missionVariables.rescuestation_reputation += 20;
		missionVariables.rescuestation_noentry = missionVariables.rescuestation_destsystem;
		missionVariables.rescuestation_noentrytime = clock.days;
		// special mission
}

this.failMission = function() {
		missionVariables.rescuestation_reputation -= 10;
		// special mission
}

this.cleanupMission = function() {
		delete missionVariables.rescuestation_reward;
		delete missionVariables.rescuestation_system;
		delete missionVariables.rescuestation_system_name;
		delete missionVariables.rescuestation_destsystem;
		delete missionVariables.rescuestation_destsystem_name;
		delete missionVariables.rescuestation_deadline;
		delete missionVariables.rescuestation_pilot;
		delete missionVariables.rescuestation_pilotdesc;
		delete missionVariables.rescuestation_agent;
		delete missionVariables.rescuestation_agentdesc;
}

this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Good luck",
													 messageKey: "rescue_scenario_4b_mission_accepted",
													 model: "rescue_station",
													 background: "rrsfl_blank_bg.png"},
													function (choice) {
															worldScripts["Rescue Stations"].acceptMission();
															worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_4b_description");
													}
												 );
				mission.markSystem(missionVariables.rescuestation_destsystem);
				
		}
}


/* Mission functions */

this.agentHacker = function() {
		if (missionVariables.rescuestation_stage < 50) {
				missionVariables.rescuestation_stage = 50;
		}
}

this.addAstroMine = function() {
		
		ampos = system.mainPlanet.position.add(system.mainPlanet.position.subtract(system.sun.position));
		system.addShips("rrs_astromine",1,ampos,5E3);
		system.addShips("asteroid",30,ampos,40E3);

}
