this.author      = "cim"; 
this.copyright   = "� 2011-2012 cim."; 
this.licence = "CC-BY-SA 3.0";
this.version     = "1.3"; 
this.name        = "Rescue Scenario 5"; 
this.description = "This script adds scenario 5 rescue mission."; 

//1.3 added background images to mission screens -spara-
//1.3 changed naming scheme -spara-

this.scenarioID = "5";



this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerScenario(this.scenarioID);
}

this.missionAvailableCount = function() {
		return 1;
}

this.missionAvailable = function() {
		if (missionVariables.rescuestation_reputation < 10) {
				return false; // insufficient reputation
		}
		if (player.bounty > 50) {
				return false; // no fugitives
		}
		if (Math.random() < 0.2) {
				return true; // rarely available
		}
		return false;
}

this.initMissionVariables = function() {
		missionVariables.rescuestation_reward = 250;
		missionVariables.rescuestation_system = system.ID;
		missionVariables.rescuestation_shipname = expandDescription("[rescue_random_shipname]");
}

this.rescue_shipDockedWithStation = function (rstation) {
		
		if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_system && missionVariables.rescuestation_stage == 100) {
				missionVariables.rescuestation_stage = 1000;
		} else {
				if (missionVariables.rescuestation_stage > 1) {
						if (missionVariables.rescuestation_stage < 1000) {
								player.commsMessage("You have docked before the rescue mission was complete. You will not be paid for this breach of contract!",7);
								worldScripts["Rescue Stations"].failMission();
						}
				}
		}
}

this.rescue_missionScreenOpportunity = function() {
		if (missionVariables.rescuestation_stage == 1) {
				mission.runScreen ({title: "Emergency escort needed",
														messageKey: "rescue_scenario_5_mission_available",
														choicesKey: "rescue_scenario_urgent_mission_choices",
														model: "rescue_station",
														background: "rrsfl_blank_bg.png"},
													 this.missionOfferDecision
													);
		} else if (missionVariables.rescuestation_stage == 1000) {
				reward = missionVariables.rescuestation_reward;
				player.credits += reward;

				mission.runScreen({title: "Escort mission completed",
													 messageKey: "rescue_scenario_5_mission_complete",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].missionSuccess();

		}
}

this.rescue_shipWillLaunchFromStation = function (rstation) {
		if (missionVariables.rescuestation_stage == 2 && rstation.hasRole("rescue_station")) {

				adddir = Vector3D.randomDirection();
				while (adddir.dot(rstation.vectorForward) < -0.5) {
						adddir = Vector3D.randomDirection();
				}
				
				tpos = rstation.position.add(adddir.multiply(15E3));
				rpos = rstation.position.add(adddir.multiply(4E3));
				ppos = rstation.position.add(adddir.multiply(25E3));

				freighter = system.addShips("rescue_freighter",1,tpos,1E3);
				freighter[0].target = rstation;
				freighter[0].setAI("rescue_scenario_5_dockingAI.plist");
				freighter[0].setScript("rescue_scenario_5_freighter.js");
				freighter[0].displayName = freighter[0].name + ": " + missionVariables.rescuestation_shipname;

			
				danger = 4+worldScripts["Rescue Stations"].dangerScale(128);

				pirates = system.addShips("pirate",danger,ppos,5E3);
				for(i=0;i<pirates.length;i++) {
						pirates[i].setScript("rescue_scenario_5_pirate.js");
						if (pirates[i].escorts) {
								for (j=0;j<pirates[i].escorts.length;j++) {
										pirates[i].escorts[j].setScript("rescue_scenario_5_pirate.js");
								}
						}
				}
				
				escorts = freighter[0].escorts;
				for (i=0;i<escorts.length;i++) {
						escorts[i].switchAI("route1patrolAI.plist");
						escorts[i].target = pirates[Math.floor(Math.random()*pirates.length)];
						escorts[i].setAI("interceptAI.plist");
				}
				
				defense = system.addShips("rrs-escort",2+Math.floor(Math.random()*2),rpos,2E3);
				for (i=0;i<defense.length;i++) {
						defense[i].switchAI("route1patrolAI.plist");
						defense[i].target = pirates[Math.floor(Math.random()*pirates.length)];
						defense[i].setAI("interceptAI.plist");
				}


				missionVariables.rescuestation_stage = 3;
		}

}

this.rescue_shipWillExitWitchspace = function() {
		if (missionVariables.rescuestation_stage < 100) {
				player.consoleMessage("You have abandoned the rescue mission");
				worldScripts["Rescue Stations"].failMission();
		}
}



/* Mission functions */

this.missionSuccess = function() {
		missionVariables.rescuestation_reputation += 10;

		worldScripts["Rescue News"].sendNews("rescue_scenario_5_news",3,0.05);
}

this.failMission = function () {
		missionVariables.rescuestation_reputation -= 5; // easy to fail through no fault of own
}

this.cleanupMission = function() {
		delete missionVariables.rescuestation_reward;
		delete missionVariables.rescuestation_system;
		delete missionVariables.rescuestation_shipname;
}

this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Downloading mission data",
													 messageKey: "rescue_scenario_5_mission_accepted",
													 choicesKey: "rescue_scenario_urgent_mission_launch",
													 model: "rrs-escort",
													 background: "rrsfl_blank_bg.png"},
													worldScripts["Rescue Scenario 5"].missionOfferAccepted
												 );
		}
}

this.missionOfferAccepted = function (choice) {
		worldScripts["Rescue Stations"].acceptMission();
		worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_5_description");
		player.ship.fuel = 7;
		player.ship.launch();
}
