this.author      = "cim"; 
this.copyright   = "� 2011-2012 cim."; 
this.licence = "CC-BY-SA 3.0";
this.version     = "1.3"; 
this.name        = "Rescue Scenario 6"; 
this.description = "This script adds scenario 6 rescue mission."; 

//1.3 added background images to mission screens without model -spara-
//1.3 fixed description expand bug -spara-

this.scenarioID = "6";

this.startUp = function() {
// make sure Rescue Stations is loaded first
		if (worldScripts["Rescue Stations"].startUp) {
				worldScripts["Rescue Stations"].startUp();
		}
		worldScripts["Rescue Stations"].registerScenario(this.scenarioID);
}

this.missionAvailableCount = function(iteration) {
		// ~75% 1, ~15% 2, ~5% 3, ~5% 4
		x = Math.sqrt(Math.random()/Math.random());
		if (x > 4) {
				return 4;
		} else if (x < 1) {
				return 1;
		} else {
				return Math.floor(x);
		}
}

this.targetSystems = function() {
		return SystemInfo.filteredSystems(this, function (other) {
				if (!((other.systemID !== system.info.systemID) && 
						(!other.sun_gone_nova) &&
						(worldScripts["Rescue Stations"].systemHasRescueStation(other.systemID)) &&
						(system.info.distanceToSystem(other) > 7) &&
							(system.info.distanceToSystem(other) <= 25))) {
						return false;
				} else {
						var route = system.info.routeToSystem(other);
						return (route && route.distance <= 25);
				}
		});
}


this.missionAvailable = function() {
		if (Math.random() > 0.75) {
				return false; // often available
		}
		if (missionVariables.rescuestation_reputation < 0) {
				return false; // bad reputation
		}
		if (player.bounty > 50) {
				return false; // no fugitives
		}
		if (this.targetSystems().length < 1) {
				return false; // no suitable systems
		}
		return true;
}

this.initMissionVariables = function() {
		missionVariables.rescuestation_system = system.ID;
		
		nearby = this.targetSystems();
		destination = nearby[Math.floor(nearby.length*Math.random())];

		missionVariables.rescuestation_destsystem = destination.systemID;
		missionVariables.rescuestation_destsystem_name = destination.name;

		direction = worldScripts["Rescue Stations"].getDirection(system.info,destination);

		missionVariables.rescuestation_destsystem_desc = destination.name+" ("+expandDescription("[rescue_govname_"+destination.government+"]")+", "+Math.round(system.info.distanceToSystem(destination))+" LY "+direction+")";

		timer = (2+Math.random())*(system.info.routeToSystem(destination).time);
		deadline = (3600*timer)+clock.seconds;

		missionVariables.rescuestation_deadline = deadline;
		missionVariables.rescuestation_deadline_text = clock.clockStringForTime(deadline);

		reward = Math.floor(system.info.routeToSystem(destination).distance * 20);
		missionVariables.rescuestation_reward = reward;

		if (Math.random() < 0.25) {
				missionVariables.rescuestation_danger = 3 + worldScripts["Rescue Stations"].dangerScale(128); 
		} else {
				missionVariables.rescuestation_danger = 0;
		}

		

}

this.rescue_shipDockedWithStation = function (rstation) {
		
		if (rstation.hasRole("rescue_station") && system.ID == missionVariables.rescuestation_destsystem && missionVariables.rescuestation_stage == 2) {
				if (clock.seconds < missionVariables.rescuestation_deadline) {
						missionVariables.rescuestation_stage = 1000;
				} else {
						missionVariables.rescuestation_stage = 1001;
				}
		}

}

this.rescue_missionScreenOpportunity = function() {
		if (missionVariables.rescuestation_stage == 1) {
				mission.runScreen ({title: "Package transportation needed",
														messageKey: "rescue_scenario_6_mission_available",
														choicesKey: "rescue_scenario_nonurgent_mission_choices",
														model: "rescue_station",
														background: "rrsfl_blank_bg.png"},
													 this.missionOfferDecision
													);
		} else if (missionVariables.rescuestation_stage == 1000) {
				reward = missionVariables.rescuestation_reward;
				player.credits += reward;

				mission.runScreen({title: "Delivery completed",
													 messageKey: "rescue_scenario_6_mission_complete",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].missionSuccess();
		} else if (missionVariables.rescuestation_stage == 1001) {
				lateness = clock.seconds - missionVariables.rescuestation_deadline;
				if (lateness > 864000) {
						lateness = 864000; // more than 10 days late and it doesn't matter
				}
				missionVariables.rescuestation_reputation += 5; // partial mitigation
				missionVariables.rescuestation_reputation -= Math.floor(lateness/86400); // each extra day late makes it worse
				
				mission.runScreen({title: "Delivery completed",
													 messageKey: "rescue_scenario_6_mission_toolate",
													 background: "rrsfl_bg.png"});

				worldScripts["Rescue Stations"].failMission();

		}
}


this.rescue_shipWillExitWitchspace = function() {
		if (missionVariables.rescuestation_danger > 0) {
				if (system.ID == missionVariables.rescuestation_destsystem) {
						appear = missionVariables.rescuestation_danger; // use all the rest
				} else {
						appear = Math.floor(Math.random()*missionVariables.rescuestation_danger);
				}
				if (appear > 1) { 
						assassins = system.addShips("rrs-vicious-hunter",appear,player.ship.position.add(Vector3D.random(14E3),1E3));
						for (i=0;i<assassins.length;i++) {
								assassin = assassins[i];
								assassin.target = player.ship;
								assassin.setAI("interceptAI.plist");
						}
						missionVariables.rescuestation_danger -= appear;					
				}
		}
}

this.rescue_shipExitedWitchspace = function() {
		assassins = system.shipsWithPrimaryRole("rrs-vicious-hunter",player.ship,25600);
		if (assassins.length > 0) {
				assassins[0].commsMessage("[rescue_scenario_6_conspirator_target]");
		}
		
}


/* Mission setup */

this.missionSuccess = function() {
		missionVariables.rescuestation_reputation += 5; // only really useful for complete beginners and restoring a damaged reputation, though it does also stop rep decay if you were going that way anyway
		// nothing special		
}

this.failMission = function () {
		missionVariables.rescuestation_reputation -= 5; // hard to get wrong
}

this.cleanupMission = function() {
		delete missionVariables.rescuestation_reward;
		delete missionVariables.rescuestation_system;
		delete missionVariables.rescuestation_danger;
		delete missionVariables.rescuestation_destsystem;
		delete missionVariables.rescuestation_destsystem_name;
		delete missionVariables.rescuestation_destsystem_desc;
		delete missionVariables.rescuestation_deadline;
		delete missionVariables.rescuestation_deadline_text;
}


this.missionOfferDecision = function (choice) {
		if (choice == "NO") {
				worldScripts["Rescue Stations"].refuseCurrentMission();
				worldScripts["Rescue Stations"].cleanupMission();
				missionVariables.rescuestation_stage = 0;
		} else {
				missionVariables.rescuestation_stage = 2;
				mission.runScreen({title: "Transferring package",
													 messageKey: "rescue_scenario_6_mission_accepted",
													 model: "rescue_blackbox",
													 background: "rrsfl_blank_bg.png"},
													function (choice) {
															worldScripts["Rescue Stations"].acceptMission();
															mission.markSystem(missionVariables.rescuestation_destsystem);
															worldScripts["Rescue Stations"].setMissionDetails("rescue_scenario_6_description");
													}
												 );
		}
}

/* Mission functions */

